# Calculations for AI Agents
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents#prerequisites)
  * [Calculation Templates](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents#calculation-templates)


Automatically calculate the business value of your AI agents.
